- [LSTM][1]

https://www.jianshu.com/p/8b78ac379e3a
![](http://ww4.sinaimg.cn/large/006tNc79ly1g59ujv0z2cj30m80e4abj.jpg)


## 语义匹配
https://github.com/bojone/margin-softmax
https://www.kaggle.com/lamdang/dl-models

---
[1]: https://www.jianshu.com/p/32d3048da5ba